@@ -1,5 +1,7 @@
 pub use object_id::ObjectIdExt;
+pub use reference::ReferenceExt;
 pub use tree::TreeIterExt;
 
 mod object_id;
+mod reference;
 mod tree;
