@@ -1,17 +1,15 @@
 #![allow(missing_docs)]
+
 use std::path::PathBuf;
 
-use crate::Kind;
-
-pub mod discover;
-pub mod is_git;
 pub use is_git::{is_bare, is_git};
 
-#[derive(Debug, Clone, Eq, PartialEq, Ord, PartialOrd, Hash)]
-pub enum Path {
-    WorkTree(PathBuf),
-    Repository(PathBuf),
-}
+use crate::{Kind, Path};
+
+///
+pub mod create;
+pub mod discover;
+pub mod is_git;
 
 impl AsRef<std::path::Path> for Path {
     fn as_ref(&self) -> &std::path::Path {
@@ -36,10 +34,10 @@ impl Path {
         }
     }
 
-    pub fn into_repository_directory(self) -> PathBuf {
+    pub fn into_repository_and_work_tree_directories(self) -> (PathBuf, Option<PathBuf>) {
         match self {
-            Path::WorkTree(path) => path.join(".git"),
-            Path::Repository(path) => path,
+            crate::Path::WorkTree(working_tree) => (working_tree.join(".git"), Some(working_tree)),
+            crate::Path::Repository(repository) => (repository, None),
         }
     }
 }
